package cn.bsl.bxbg.zhiban.view;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.LinearLayout;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import butterknife.BindView;
import butterknife.ButterKnife;
import butterknife.OnClick;
import cn.bsl.bxbg.zhiban.BaseActivity;
import cn.bsl.bxbg.zhiban.R;
import cn.bsl.bxbg.zhiban.adapter.ZbPeopleAdapter;
import cn.bsl.bxbg.zhiban.bean.TimeBean;
import cn.bsl.bxbg.zhiban.net.client.DutyPlanClient;
import cn.bsl.bxbg.zhiban.net.response.CCDuties;
import cn.bsl.bxbg.zhiban.utils.Constant;
import cn.bsl.bxbg.zhiban.utils.DateUtils;
import io.reactivex.android.schedulers.AndroidSchedulers;
import io.reactivex.schedulers.Schedulers;
import retrofit2.Call;
import retrofit2.Callback;
import retrofit2.Response;

public class ZhibanDetailsActivity extends BaseActivity {

    @BindView(R.id.tvTiaoban)
    TextView tvTiaoban;
    @BindView(R.id.start_zb)
    LinearLayout startZb;
    @BindView(R.id.duty_dept)
    TextView dutyDept;
    @BindView(R.id.tb)
    LinearLayout tb;
    @BindView(R.id.tvZhiban)
    TextView tvZhiban;
    @BindView(R.id.tbs)
    LinearLayout tbs;
    private List<CCDuties> ccDutiesList = new ArrayList<>();
    @BindView(R.id.duty_time)
    TextView dutyTime;
    @BindView(R.id.zb_people)
    ListView zbPeople;
    DutyPlanClient dutyPlanClient = new DutyPlanClient();
    private String dutyId;
    private String shift;
    private String dutyTimes;
    private String tomorrowMorning;
    private CCDuties netClcDuties;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_zhiban_details);
        ButterKnife.bind(this);
        initData();
        initTime();
        nextTime();
    }

    private void nextTime() {
        Calendar tomorrowDate = DateUtils.getTomorrowDate(dutyTimes);
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd");
        String date = sdf.format(tomorrowDate.getTime());
        dutyPlanClient.findPeopleByTime(date)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(ccDuties -> {
                    if (ccDuties != null && ccDuties.size() > 0) {
                        tomorrowMorning = ccDuties.get(0).getMorning();
                    }
                }, Throwable::printStackTrace);
    }

    private void initTime() {
        dutyPlanClient.timeBean().enqueue(new Callback<TimeBean>() {
            @Override
            public void onResponse(Call<TimeBean> call, Response<TimeBean> response) {
                Constant.systemDate = response.body().getSystemDate();
                Constant.systemTime = response.body().getSystemTime();
            }

            @Override
            public void onFailure(Call<TimeBean> call, Throwable t) {
                t.printStackTrace();
            }
        });
    }

    private void initData() {
        // 拿ZhibanInfo传入的早中晚数据进行调班，但是展示需要使用dutyId查询出当天所有的记录.
        dutyId = getIntent().getStringExtra("dutyId");
        String classLeader = getIntent().getStringExtra("dutyLeader") + "";
        String morning = getIntent().getStringExtra("dutyPersonMorning") + "";
        String noon = getIntent().getStringExtra("dutyPersonNoon") + "";
        String evening = getIntent().getStringExtra("dutyPersonEvening") + "";
        dutyTimes = getIntent().getStringExtra("dutyTime") + "";
        shift = getIntent().getStringExtra("shift") + "";
        CCDuties ccDuties = new CCDuties();
        ccDuties.setId(dutyId);
        ccDuties.setClassLeaders(classLeader);
        ccDuties.setMorning(morning);
        ccDuties.setNoon(noon);
        ccDuties.setEvening(evening);
        ccDuties.setDutyDate(dutyTimes);
        ccDutiesList.add(ccDuties);
        queryDetails(dutyId);
    }

    private void queryDetails(String dutyId) {
        dutyPlanClient.dutiesById(dutyId)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(clcDuties -> {
                    netClcDuties = clcDuties;
//                    ccDutiesList.clear();
                    dutyTime.setText(clcDuties.getDutyDate());
                    dutyDept.setText(clcDuties.getDepartment());
//                    ccDutiesList.add(clcDuties);
                    List<CCDuties> ccDuties = new ArrayList<CCDuties>();
                    ccDuties.add(clcDuties);
                    zbPeople.setAdapter(new ZbPeopleAdapter(ccDuties));
                }, Throwable::printStackTrace);
    }


    @OnClick({R.id.tb, R.id.start_zb})
    public void onViewClicked(View view) {
        switch (view.getId()) {
            case R.id.tb:
                Intent intent = new Intent(this, TiaoBanPublish.class);
                intent.putExtra("id", dutyId);
                intent.putExtra("morning", ccDutiesList.get(0).getMorning());
                intent.putExtra("noon", ccDutiesList.get(0).getNoon());
                intent.putExtra("evening", ccDutiesList.get(0).getEvening());
                intent.putExtra("dutyTime", dutyTime.getText().toString());
                intent.putExtra("leaderChange", ccDutiesList.get(0).getClassLeaders());
                intent.putExtra("department", netClcDuties.getDepartment());
                startActivity(intent);
                break;
            case R.id.start_zb:
                // 如果班次为早班， 那么需要传入中班A岗的人员，如果是中班， 需要拿到晚班的A岗，如果是晚班
                // ，需要拿第二天值班的早班
                String nextPeople = "数据错误";
                if (shift.equals("2")) {
                    String[] split = tomorrowMorning.split(",");
                    nextPeople = split[0];
                } else if (shift.equals("0")) {
                    // 早班拿中班
                    String[] split = netClcDuties.getNoon().split(",");
                    nextPeople = split[0];
                } else if (shift.equals("1")) {
                    // 中班拿晚班
                    String[] split = netClcDuties.getEvening().split(",");
                    nextPeople = split[0];

                }
                dutyPlanClient.shiftNew(dutyId, nextPeople, ccDutiesList.get(0).getDepartment(),
                        ccDutiesList.get(0).getDutyDate(), shift)
                        .subscribeOn(Schedulers.io())
                        .observeOn(AndroidSchedulers.mainThread())
                        .subscribe(shiftBean -> {
                            Toast.makeText(this, "开始值班，您可以在交接班记录编辑您的值班记录", Toast.LENGTH_SHORT).show();
                            finish();
                        }, Throwable::printStackTrace);
                break;
        }
    }
}
